@@ -1,4 +1,5 @@
 import os
+import enum
 from typing import Dict
 
 from fastapi import FastAPI
@@ -10,82 +11,48 @@ from swole.core.utils import route_to_filename
 from swole.widgets import Widget
 
 
-SWOLE_CACHE = "~/.cache/swole"
+SWOLE_CACHE = "~/.cache/swole"      #: Default directory to use for caching.
 
 
 class Application():
-    """ Class representing an application. An application is the englobing,
-    object, which list all possible routes.
+    """ Class representing an application. Application are used to serve
+    declared pages.
 
     Attributes:
-        pages (`dict`): Dictionary[`str`: `Page`] listing all possible routes
-            and their corresponding Page.
-        files (`dict`): Dictionary[`str`: `str`] listing all possible routes and
-            their corresponding saved HTML file. This attribute is set only
-            after calling the method `write()`.
         fapi (`fastapi.FastAPI`): FastAPI app.
     """
-    def __init__(self, pages=None):
-        """ Constructor.
-
-        Arguments:
-            pages (`list`, optional): List of `Page`. Defaults to `None`.
-        """
-        self.pages = {p.route: p for p in pages} if pages is not None else {}
+    def __init__(self):
         self.files = None
         self.fapi = FastAPI()
 
-    def add(self, pages):
-        """ Method to add pages to the application.
-
-        Arguments:
-            pages (`Page` or `list`): Page or list of Page to add.
-        """
-        if isinstance(pages, list):
-            for page in pages:
-                self._add(page)
-        else:
-            self._add(pages)
-
-    def _add(self, page):
-        if not isinstance(page, Page):
-            raise ValueError("Expected a Page type, got a {} type instead".format(type(page)))
-
-        if page.route in self.pages:
-            raise ValueError("This route ({}) is already set".format(page.route))
-
-        self.pages[page.route] = page
-
     def assign_orphan_widgets(self):
         """ Method finding orphan widgets if any, and assigning it to the Home
-        page if there is no Home page already. This allow a very simple and easy
-        way to use the library.
+        page. If the home page does not exist, create it. This allow a very
+        simple and easy way to use the library.
         """
-        if HOME_ROUTE in self.pages:
-            # Home page already defined, nothing to do
-            return
+        if HOME_ROUTE not in Page._dict:
+            # No home page : create one
+            Page()
 
-        home = Page()
-        assigned_widgets = set().union(*[page.widgets for page in self.pages.values()])
+        home = Page._dict[HOME_ROUTE]
+        assigned_widgets = set().union(*[page.widgets for page in Page._dict.values()])
         for w in Widget._declared:
             if w not in assigned_widgets:       # Orphan !
                 home.add(w)
 
-        self.pages[HOME_ROUTE] = home
-
     def write(self, folder=SWOLE_CACHE):
         """ Method to write the HTML of the application to files, in order to
         later serve it.
 
         Arguments:
             folder (`str`, optional): Folder where to save HTML files. Defaults
-                to SWOLE_CACHE.
+                to :const:`~swole.core.application.SWOLE_CACHE`.
         """
         os.makedirs(folder, exist_ok=True)
 
         self.files = {}         # Route -> HTML file
         self.callbacks = {}     # Callback ID -> (Page, Ajax)
-        for route, page in self.pages.items():
+        for route, page in Page._dict.items():
             # Write HTML of the page
             html_str = page.html().render()
             path = os.path.join(folder, "{}.html".format(route_to_filename(route)))
@@ -95,7 +62,7 @@ class Application():
 
             # Save also callbacks (along with their page)
             for aj in page.ajax():
-                self.callbacks[str(aj.id)] = (page, aj)
+                self.callbacks[aj.id] = (page, aj)
 
     def define_routes(self):
         """ Method defining the routes in the FastAPI app, to display the right
@@ -108,17 +75,21 @@ class Application():
                 return FileResponse(html_file)
 
         # Define the callback route
-        @self.fapi.post("/callback/{callback_id}")
-        def callback(callback_id, inputs: Dict[str, str]):
-            page, ajax = self.callbacks[callback_id]
-            return ajax(page, inputs)
+        if len(self.callbacks) != 0:
+            # Define a dynamic enum to ensure only specific callback ID are valid
+            cbe = enum.IntEnum('CallbackEnum', {str(c_id): c_id for c_id in self.callbacks.keys()})
+
+            @self.fapi.post("/callback/{callback_id}")
+            def callback(callback_id: cbe, inputs: Dict[str, str]):
+                page, ajax = self.callbacks[callback_id]
+                return ajax(page, inputs)
 
     def serve(self, folder=SWOLE_CACHE, host='0.0.0.0', port=8000, log_level='info'):
         """ Method to fire up the FastAPI server !
 
         Arguments:
             folder (`str`, optional): Folder where to save HTML files. Defaults
-                to SWOLE_CACHE.
+                to :const:`~swole.core.application.SWOLE_CACHE`.
             host (`str`, optional): Run FastAPI on this host. Defaults to
                 `0.0.0.0`.
             port (`int`, optional): Run FastAPI on this port. Defaults to
