@@ -1,18 +1,12 @@
 from dominate.tags import button
 
-from swole.widgets.base import Widget
+from swole.widgets.base import WideWidget
 
 
-class Button(Widget):
-    """ Widget to create a button.
-
-    Attributes:
-        text (`str`): Text of the button.
-        primary (`bool`): Wether this button is primary or not.
-    """
+class Button(WideWidget):
+    """ Widget to create a button. """
     def __init__(self, text="Button", primary=False, onclick=None, **kwargs):
-        """ Constructor.
-
+        """
         Arguments:
             text (`str`, optional): Text of the button. Defaults to `Button`.
             primary (`bool`, optional): Wether this button is primary or not.
